@@ -740,7 +740,7 @@ class Camera(BaseCamera):
                             MODE_DM=MODE_DMbase+"T"
 
                         senh.setbox(MODE_DM, senh.MODE) #---push UP to avoid DetMot
-                        print("D... detecting motion")
+                        #print("D... detecting motion")
                         senh.detmo( average, blur)
                         senh.chk_threshold( threshold )
                         if senh.motion_detected: # saving avi on mation detect
