@@ -167,7 +167,10 @@ def remap_keys(key):
 # ctrla
 
     if key in table:
-        key = ord( table[key] )
+        #key = ord( table[key] )
+        keynew = table[key]
+        #print(f"in remaping {key} - {keynew}")
+        return keynew
     return key
 
 
@@ -419,10 +422,11 @@ Recommendation:
         sfilenamea = os.path.expanduser("~/DATA/" + sfilenamea)
         # codec
         sfourcc = cv2.VideoWriter_fourcc(*'XVID')
-        # sfourcc = cv2.VideoWriter_fourcc(*'LAGS') # lossless NOT mkv,avi..,
-        sfourcc = cv2.VideoWriter_fourcc(*'X264') # +avi small
-        #sfourcc = cv2.VideoWriter_fourcc(*'MP4V')
-        #sfourcc = cv2.VideoWriter_fourcc(*'IYUV') # huge + avi
+        #### sfourcc = cv2.VideoWriter_fourcc(*'LAGS') # lossless NOT mkv,avi
+        #sfourcc = cv2.VideoWriter_fourcc(*'X264') # +avi small NOTubu22
+        sfourcc = cv2.VideoWriter_fourcc(*'mp4v') # works on UBU22 clean inst
+        #####sfourcc = cv2.VideoWriter_fourcc(*'MP4V')
+        #####sfourcc = cv2.VideoWriter_fourcc(*'IYUV') # huge + avi
         #  25 FPS
         saviout = cv2.VideoWriter( sfilenamea,sfourcc,25.0, resolution )
         print( sfilenamea )
@@ -811,7 +815,17 @@ Recommendation:
                 #   hack-expand;  tracker; zoom; rotate; save; measure
 
                 # cv2.namedWindow( wname, cv2.WINDOW_KEEPRATIO ,cv2.WINDOW_GUI_EXPANDED)
-                cv2.namedWindow( wname , cv2.WINDOW_KEEPRATIO ) # 2 may allow resize on gigavg
+                #
+                # cv2.WINDOW_KEEPRATIO 2 may allow resize on gigavg
+                # but troja...
+                #
+                # https://stackoverflow.com/a/43497012
+                #
+
+
+                #cv2.namedWindow( wname , cv2.WINDOW_KEEPRATIO ) #
+                # QT cv2.namedWindow( wname , cv2.WINDOW_GUI_NORMAL + cv2.WINDOW_OPENGL  ) #
+                cv2.namedWindow( wname , cv2.WINDOW_GUI_NORMAL   ) #
                 # cv2.namedWindow( wname , 2 ) # 2 may allow resize on gigavg
                 if frames_total < 2:
                     #cv2.namedWindow(wname,cv2.WND_PROP_FULLSCREEN)
@@ -1289,8 +1303,11 @@ in progress"""
                 # cv2.namedWindow(rpi_name, cv2.WINDOW_GUI_EXPANDED)
                 # time.sleep(0.2)
                 cv2.setMouseCallback(rpi_name, MOUSE)
+                #key = cv2.waitKey(1) # same problem with shift on ubu22 as ex
                 key = cv2.waitKeyEx(1)
+                #print(f" read {key}")
                 key = remap_keys(key) # make compatible with waitKey()
+                #print(f"remapped {key}")
 
 
 
